import { ILayoutRestorer } from '@jupyterlab/application';
import { ICommandPalette, WidgetTracker } from "@jupyterlab/apputils";
import { JSONExt } from "@phosphor/coreutils";
import { IFileBrowserFactory } from '@jupyterlab/filebrowser';
import { SubmitNotebookButtonExtension } from "./SubmitNotebook";
import { NotebookExperimentWidget } from "./NotebookExperiments";
export * from './BrowseFileDialog';
import '../style/index.css';
/**
 * A JupyterLab extension to submit notebooks to
 * be executed in a remote platform
 */
export const dlw_extension = {
    id: 'dlw-extension',
    requires: [ICommandPalette, ILayoutRestorer, IFileBrowserFactory],
    autoStart: true,
    activate: (app, palette, restorer, browserFactory) => {
        console.log('Activating Deep Learning Workspace JupyterLab extension!');
        // Extension initialization code
        let buttonExtension = new SubmitNotebookButtonExtension(app, browserFactory);
        app.docRegistry.addWidgetExtension('Notebook', buttonExtension);
        app.contextMenu.addItem({
            selector: '.jp-Notebook',
            command: 'notebook:submit',
            rank: -0.5
        });
        // Declare a widget variable
        let notebookExperimentWidget;
        setInterval(() => {
            if (notebookExperimentWidget) {
                console.log('>>> timer expired... will refresh experiment list');
                notebookExperimentWidget.update();
            }
        }, 10 * 1000);
        // Add an application command
        const command = 'dlw:open-experiments';
        app.commands.addCommand(command, {
            label: 'Notebook Experiments',
            execute: () => {
                if (!notebookExperimentWidget) {
                    // Create a new widget if one does not exist
                    notebookExperimentWidget = new NotebookExperimentWidget();
                    notebookExperimentWidget.update();
                }
                if (!tracker.has(notebookExperimentWidget)) {
                    // Track the state of the widget for later restoration
                    tracker.add(notebookExperimentWidget);
                }
                if (!notebookExperimentWidget.isAttached) {
                    // Attach the widget to the main work area if it's not there
                    app.shell.add(notebookExperimentWidget, 'main');
                }
                else {
                    // Refresh the comic in the widget
                    notebookExperimentWidget.update();
                }
                // Add as right side panel
                app.shell.add(notebookExperimentWidget, 'right');
                // Activate the widget
                app.shell.activateById(notebookExperimentWidget.id);
            }
        });
        // Add the command to the palette.
        palette.addItem({ command, category: 'Deep Learning Workspace' });
        // Track and restore the widget state
        let tracker = new WidgetTracker({ namespace: 'dlw' });
        restorer.restore(tracker, {
            command,
            args: () => JSONExt.emptyObject,
            name: () => 'dlw'
        });
    }
};
export default dlw_extension;
